==> activity-common-api-1.1.34-20180711.052824-8-sources.jar: cn/com/duiba/activity/common/center/api/dto/sharecode/InviteBonusRecordDto.java <==
package cn.com.duiba.activity.common.center.api.dto.sharecode;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author zhangruofan
 * @date 2018/04/11
 */
public class InviteBonusRecordDto implements Serializable {
    private static final long serialVersionUID = 4255391861492126353L;

    private Long bizId;
    private String shareCode;
    private Integer userType;
    private Integer ruleType;
    private String ruleConfig;
    private String activityType;
    private Long activityId;
    private Long appId;
    private Long consumerId;
    private Integer recordStatus;
    private String recordErrMsg;
    private String bonusDetail;

    public Long getBizId() {
        return bizId;
    }

    public void setBizId(Long bizId) {
        this.bizId = bizId;
    }

    public String getShareCode() {
        return shareCode;
    }

    public void setShareCode(String shareCode) {
        this.shareCode = shareCode;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Integer getRuleType() {
        return ruleType;
    }

    public void setRuleType(Integer ruleType) {
        this.ruleType = ruleType;
    }

    public String getRuleConfig() {
        return ruleConfig;
    }

    public void setRuleConfig(String ruleConfig) {
        this.ruleConfig = ruleConfig;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getRecordStatus() {
        return recordStatus;
    }

    public void setRecordStatus(Integer recordStatus) {
        this.recordStatus = recordStatus;
    }

    public String getRecordErrMsg() {
        return recordErrMsg;
    }

    public void setRecordErrMsg(String recordErrMsg) {
        this.recordErrMsg = recordErrMsg;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

    public String getBonusDetail() {
        return bonusDetail;
    }

    public void setBonusDetail(String bonusDetail) {
        this.bonusDetail = bonusDetail;
    }
}

==> activity-common-api-1.3.71-sources.jar: cn/com/duiba/activity/common/center/api/dto/sharecode/InviteBonusRecordDto.java <==
package cn.com.duiba.activity.common.center.api.dto.sharecode;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * @author zhangruofan
 * @date 2018/04/11
 */
public class InviteBonusRecordDto implements Serializable {
    private static final long serialVersionUID = 4255391861492126353L;

    private Long bizId;
    private String shareCode;
    private Integer userType;
    private Integer ruleType;
    private String ruleConfig;
    private String activityType;
    private Long activityId;
    private Long appId;
    private Long consumerId;
    private Integer recordStatus;
    private String recordErrMsg;
    private String bonusDetail;
    private Date gmtCreate;

    public Long getBizId() {
        return bizId;
    }

    public void setBizId(Long bizId) {
        this.bizId = bizId;
    }

    public String getShareCode() {
        return shareCode;
    }

    public void setShareCode(String shareCode) {
        this.shareCode = shareCode;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Integer getRuleType() {
        return ruleType;
    }

    public void setRuleType(Integer ruleType) {
        this.ruleType = ruleType;
    }

    public String getRuleConfig() {
        return ruleConfig;
    }

    public void setRuleConfig(String ruleConfig) {
        this.ruleConfig = ruleConfig;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getRecordStatus() {
        return recordStatus;
    }

    public void setRecordStatus(Integer recordStatus) {
        this.recordStatus = recordStatus;
    }

    public String getRecordErrMsg() {
        return recordErrMsg;
    }

    public void setRecordErrMsg(String recordErrMsg) {
        this.recordErrMsg = recordErrMsg;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

    public String getBonusDetail() {
        return bonusDetail;
    }

    public void setBonusDetail(String bonusDetail) {
        this.bonusDetail = bonusDetail;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}
